Changes
*******

0.3.2 (2015-mm-dd)
==================

* fixed malleefowl default port in dockerfile template.
* changed dockerfile volumes.

0.3.1 (2015-09-24)
==================

* updated Dockerfile template.
* added output-port option.

0.3.0 (2015-09-22)
==================

* updated Dockerfile tempalte.
* more options added.

0.2.2 (2015-08-05)
==================

* cleaned up ... removed conda dependency.
* update to buildout 2.x.

0.2.1 (2015-04-13)
==================

* Updated Dockerfile template for CentOS builds (sudo was missing).

0.2.0 (2015-03-16)
==================

* Updated Dockerfile template for birdhouse environments.

0.1.1 (2014-11-13)
==================

* Updated Dockerfile template
starts only supervisord.
* Fixed example in Readme.

0.1.0 (2014-11-05)
==================

* Initial Release.
